.. include:: tutorials/README.rst

.. toctree::
    :maxdepth: 1

    tutorials/tut_intro.ipynb
    tutorials/tut_plotting.ipynb
    tutorials/tut_running.ipynb
    tutorials/tut_people.ipynb
    tutorials/tut_interventions.ipynb
    tutorials/tut_analyzers.ipynb
    tutorials/tut_calibration.ipynb
    tutorials/tut_immunity.ipynb
    tutorials/tut_deployment.ipynb
    tutorials/tut_tips.ipynb
    tutorials/tut_advanced.ipynb
    
